
# Type: increases mutation rate of


holds between a molecular entity and a genomic entity where the action or effect of the molecular entity increases the rate of mutation of the genomic entity within a system of interest

URI: [biolink:increases_mutation_rate_of](https://w3id.org/biolink/vocab/increases_mutation_rate_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) ->  <sub>0..*</sub> [GenomicEntity](GenomicEntity.md)

## Parents

 *  is_a: [affects mutation rate of](affects_mutation_rate_of.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [Carbohydrate](Carbohydrate.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [CodingSequence](CodingSequence.md)
 * [Drug](Drug.md)
 * [Exon](Exon.md)
 * [Gene](Gene.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [Haplotype](Haplotype.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [MolecularEntity](MolecularEntity.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [SequenceVariant](SequenceVariant.md)
 * [Transcript](Transcript.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |

